@@ -15,7 +15,7 @@
             x0 <- x1 - h * (x1 - x0)/d0
             y0 <- y1 - h * (y1 - y0)/d0
             if (edge) 
-                arrows(x0, y0, x1, y1, ang = ang, len = len, 
+                arrows(x0, y0, x1, y1, angle = ang, length = len, 
                   lty = 1)
         }
     }
